@@ -9,10 +9,12 @@ function HistoryListModel(parent) {
     self.lastUpdate = 0;
     self.historyItems = ko.observableArray([])
     self.showFailed = ko.observable(false).extend({ persist: 'historyShowFailed' });
+    self.showArchive = ko.observable(false).extend({ persist: 'historyShowArchive' });
     self.isLoading = ko.observable(false).extend({ rateLimit: 100 });
     self.searchTerm = ko.observable('').extend({ rateLimit: { timeout: 400, method: "notifyWhenChangesStop" } });
     self.paginationLimit = ko.observable(10).extend({ persist: 'historyPaginationLimit' });
     self.totalItems = ko.observable(0);
+    self.deleteItems = ko.observableArray([]);
     self.ppItems = ko.observable(0);
     self.pagination = new paginationModel(self);
     self.isMultiEditing = ko.observable(false).extend({ persist: 'historyIsMultiEditing' });
@@ -43,7 +45,7 @@ function HistoryListModel(parent) {
         var newItems = [];
         $.each(data.slots, function(index, slot) {
             var existingItem = ko.utils.arrayFirst(self.historyItems(), function(i) {
-                return i.historyStatus.nzo_id() == slot.nzo_id;
+                return i.historyStatus.nzo_id() === slot.nzo_id;
             });
             // Set index in the results
             slot.index = index
@@ -59,7 +61,7 @@ function HistoryListModel(parent) {
         });
 
         // Remove all items
-        if(itemIds.length == self.paginationLimit()) {
+        if(itemIds.length === self.paginationLimit()) {
             // Replace it, so only 1 Knockout DOM-update!
             self.historyItems(newItems);
             newItems = [];
@@ -68,7 +70,7 @@ function HistoryListModel(parent) {
             $.each(itemIds, function() {
                 var id = this.toString();
                 self.historyItems.remove(ko.utils.arrayFirst(self.historyItems(), function(i) {
-                    return i.historyStatus.nzo_id() == id;
+                    return i.historyStatus.nzo_id() === id;
                 }));
             });
         }
@@ -82,7 +84,7 @@ function HistoryListModel(parent) {
             if(self.parent.queue.multiEditItems().length > 0) {
                 $.each(newItems, function() {
                     var currentItem = this;
-                    self.parent.queue.multiEditItems.remove(function(inList) { return inList.id == currentItem.id; })
+                    self.parent.queue.multiEditItems.remove(function(inList) { return inList.id === currentItem.id; })
                 })
             }
         }
@@ -118,6 +120,27 @@ function HistoryListModel(parent) {
         self.parent.refresh(true)
     });
 
+    self.triggerRemoveDownload = function(items) {
+        // Show and fill modal
+        self.deleteItems.removeAll()
+
+        // Single or multiple items?
+        if(items.length) {
+            ko.utils.arrayPushAll(self.deleteItems, items)
+        } else {
+            self.deleteItems.push(items)
+        }
+
+        // Show modal or delete right away
+        if(self.parent.confirmDeleteHistory()) {
+            // Open modal if desired
+            $('#modal-delete-history-job').modal("show")
+        } else {
+            // Otherwise just submit right away
+            $('#modal-delete-history-job form').submit()
+        }
+    }
+
     // Retry a job
     self.retryJob = function(form) {
         // Adding a extra retry file happens through this special function
@@ -148,7 +171,7 @@ function HistoryListModel(parent) {
     // Searching in history (rate-limited in declaration)
     self.searchTerm.subscribe(function() {
         // Go back to page 1
-        if(self.pagination.currentPage() != 1) {
+        if(self.pagination.currentPage() !== 1) {
             // This forces a refresh
             self.pagination.moveToPage(1);
         } else {
@@ -160,13 +183,13 @@ function HistoryListModel(parent) {
     // Clear searchterm
     self.clearSearchTerm = function(data, event) {
         // Was it escape key or click?
-        if(event.type == 'mousedown' || (event.keyCode && event.keyCode == 27)) {
+        if(event.type === 'mousedown' || (event.keyCode && event.keyCode === 27)) {
             // Set the loader so it doesn't flicker and then switch
             self.isLoading(true)
             self.searchTerm('');
         }
         // Was it click and the field is empty? Then we focus on the field
-        if(event.type == 'mousedown' && self.searchTerm() == '') {
+        if(event.type === 'mousedown' && self.searchTerm() === '') {
             $(event.target).parents('.search-box').find('input[type="text"]').focus()
             return;
         }
@@ -176,10 +199,17 @@ function HistoryListModel(parent) {
 
     // Toggle showing failed
     self.toggleShowFailed = function(data, event) {
-        // Set the loader so it doesn't flicker and then switch
-        self.isLoading(true)
         self.showFailed(!self.showFailed())
-        // Forde hide tooltip so it doesn't linger
+        // Force hide tooltip so it doesn't linger
+        $('#history-options a').tooltip('hide')
+        // Force refresh
+        self.parent.refresh(true)
+    }
+
+    // Toggle showing archive
+    self.toggleShowArchive = function(data, event) {
+        self.showArchive(!self.showArchive())
+        // Force hide tooltip so it doesn't linger
         $('#history-options a').tooltip('hide')
         // Force refresh
         self.parent.refresh(true)
@@ -201,30 +231,28 @@ function HistoryListModel(parent) {
 
     // Empty history options
     self.emptyHistory = function(data, event) {
-        // Make sure no flickering
-        self.isLoading(true)
-
         // What event?
         var whatToRemove = $(event.target).data('action');
+        var skipArchive = $('#modal-purge-history input[type="checkbox"]').prop("checked")
         var del_files, value;
 
         // Purge failed
-        if(whatToRemove == 'history-purge-failed') {
+        if(whatToRemove === 'history-purge-failed') {
             del_files = 0;
             value = 'failed';
         }
         // Also remove files
-        if(whatToRemove == 'history-purgeremove-failed') {
+        if(whatToRemove === 'history-purgeremove-failed') {
             del_files = 1;
             value = 'failed';
         }
         // Remove completed
-        if(whatToRemove == 'history-purge-completed') {
+        if(whatToRemove === 'history-purge-completed') {
             del_files = 0;
             value = 'completed';
         }
         // Remove the ones on this page
-        if(whatToRemove == 'history-purge-page') {
+        if(whatToRemove === 'history-purge-page') {
             // List all the ID's
             var strIDs = '';
             $.each(self.historyItems(), function(index) {
@@ -238,6 +266,7 @@ function HistoryListModel(parent) {
                 mode: 'history',
                 name: 'delete',
                 del_files: 1,
+                archive: (!skipArchive) * 1,
                 value: strIDs
             }).then(function() {
                 // Clear search, refresh and hide
@@ -252,8 +281,9 @@ function HistoryListModel(parent) {
         callAPI({
             mode: 'history',
             name: 'delete',
-            value: value,
-            del_files: del_files
+            del_files: del_files,
+            archive: (!skipArchive) * 1,
+            value: value
         }).then(function() {
             self.parent.refresh();
             $("#modal-purge-history").modal('hide');
@@ -264,8 +294,144 @@ function HistoryListModel(parent) {
     self.showMultiEdit = function() {
         self.isMultiEditing(!self.isMultiEditing())
         self.multiEditItems.removeAll();
-        $('.history-table input[name="multiedit"], #history-options #multiedit-checkall').prop({'checked': false, 'indeterminate': false})
+        $('.history-table input[name="multiedit"], #multiedit-checkall-history').prop({'checked': false, 'indeterminate': false})
     }
+
+    // Add to the list
+    self.addMultiEdit = function(item, event) {
+        // Is it a shift-click?
+        if(event.shiftKey) {
+            checkShiftRange('.history-table input[name="multiedit"]');
+        }
+
+        // Add or remove from the list?
+        if(event.currentTarget.checked) {
+            // Add item
+            self.multiEditItems.push(item);
+        } else {
+            // Go over them all to know which one to remove
+            self.multiEditItems.remove(function(inList) { return inList.id == item.id; })
+        }
+
+        // Update check-all buton state
+        setCheckAllState('#multiedit-checkall-history', '.history-table input[name="multiedit"]')
+        return true;
+    }
+
+    // Check all
+    self.checkAllJobs = function(item, event) {
+        // Get which ones we care about
+        var allChecks = $('.history-table input[name="multiedit"]').filter(':not(:disabled):visible');
+
+        // We need to re-evaltuate the state of this check-all
+        // Otherwise the 'inderterminate' will be overwritten by the click event!
+        setCheckAllState('#multiedit-checkall-history', '.history-table input[name="multiedit"]')
+
+        // Now we can check what happend
+        // For when some are checked, or all are checked (but not partly)
+        if(event.target.indeterminate || (event.target.checked && !event.target.indeterminate)) {
+            var allActive = allChecks.filter(":checked")
+            // First remove the from the list
+            if(allActive.length == self.multiEditItems().length) {
+                // Just remove all
+                self.multiEditItems.removeAll();
+                // Remove the check
+                allActive.prop('checked', false)
+            } else {
+                // Remove them seperate
+                allActive.each(function() {
+                    // Go over them all to know which one to remove
+                    var item = ko.dataFor(this)
+                    self.multiEditItems.remove(function(inList) { return inList.id == item.id; })
+                    // Remove the check of this one
+                    this.checked = false;
+                })
+            }
+        } else {
+            // None are checked, so check and add them all
+            allChecks.prop('checked', true)
+            allChecks.each(function() { self.multiEditItems.push(ko.dataFor(this)) })
+            event.target.checked = true
+        }
+        // Set state of all the check-all's
+        setCheckAllState('#multiedit-checkall-history', '.history-table input[name="multiedit"]')
+        return true;
+    }
+
+    // Remove downloads from history
+    self.removeDownloads = function(form) {
+        // Hide modal and show notification
+        $('#modal-delete-history-job').modal("hide")
+        showNotification('.main-notification-box-removing')
+
+        var strIDsPP = '';
+        var strIDsHistory = '';
+        $.each(self.deleteItems(), function(index) {
+            // Split in jobs that need post-processing aborted, and jobs that need to be deleted
+            if(this.processingDownload() === 2) {
+                strIDsPP = strIDsPP + this.id + ',';
+                // These items should not be listed in the deletedItems later on
+                // as active post-processing aren't removed from the history output
+                self.deleteItems.remove(this)
+            } else {
+                strIDsHistory = strIDsHistory + this.id + ',';
+            }
+        })
+
+        // Trigger post-processing aborting
+        if(strIDsPP !== "") {
+            callAPI({
+                mode: 'cancel_pp',
+                value: strIDsPP
+            }).then(function(response) {
+                // Only hide and refresh
+                self.parent.refresh();
+                hideNotification()
+            });
+        }
+        if(strIDsHistory !== "") {
+            var skipArchive = $('#modal-delete-history-job input[type="checkbox"]').prop("checked")
+            callAPI({
+                mode: 'history',
+                name: 'delete',
+                del_files: 1,
+                archive: (!skipArchive) * 1,
+                value: strIDsHistory
+            }).then(function(response) {
+                self.historyItems.removeAll(self.deleteItems());
+                self.multiEditItems.removeAll(self.deleteItems())
+                self.parent.refresh();
+                hideNotification()
+            });
+        }
+    };
+
+    // Delete all selected
+    self.doMultiDelete = function() {
+        // Anything selected?
+        if(self.multiEditItems().length < 1) return;
+
+        // Trigger modal
+        self.triggerRemoveDownload(self.multiEditItems())
+    }
+
+    // Focus on the confirm button
+    $('#modal-delete-history-job').on("shown.bs.modal", function() {
+        $('#modal-delete-history-job .btn[type="submit"]').focus()
+    })
+
+    // On change of page we need to check all those that were in the list!
+    self.historyItems.subscribe(function() {
+        // We need to wait until the unit is actually finished rendering
+        setTimeout(function() {
+            $.each(self.multiEditItems(), function(index) {
+                $('#multiedit_' + this.id).prop('checked', true);
+            })
+
+            // Update check-all buton state
+            setCheckAllState('#multiedit-checkall-history', '.history-table input[name="multiedit"]')
+        }, 100)
+    }, null, "arrayChange")
 }
 
 /**
@@ -316,14 +482,14 @@ function HistoryModel(parent, data) {
 
     // Waiting?
     self.processingWaiting = ko.pureComputed(function() {
-        return(self.status() == 'Queued')
+        return(self.status() === 'Queued')
     })
 
     // Processing or done?
     self.processingDownload = ko.pureComputed(function() {
         var status = self.status();
         // When we can cancel
-        if (status === 'Extracting' || status === 'Verifying' || status == 'Repairing' || status === 'Running') {
+        if (status === 'Extracting' || status === 'Verifying' || status === 'Repairing' || status === 'Running') {
             return 2
         }
         // These cannot be cancelled
@@ -357,7 +523,7 @@ function HistoryModel(parent, data) {
                     try {
                         // Extract the Download section
                         var downloadLog = ko.utils.arrayFirst(self.historyStatus.stage_log(), function(item) {
-                            return item.name() == 'Download'
+                            return item.name() === 'Download'
                         });
                         // Extract the speed
                         return downloadLog.actions()[0].match(/(\S*\s\S+)(?=<br\/>)/)[0]
@@ -366,7 +532,7 @@ function HistoryModel(parent, data) {
                 return;
             case 'category':
                 // Exception for *
-                if(self.historyStatus.category() == "*")
+                if(self.historyStatus.category() === "*")
                     return glitterTranslate.defaultText
                 return self.historyStatus.category();
             case 'size':
@@ -431,35 +597,4 @@ function HistoryModel(parent, data) {
             return false;
         })
     }
-
-    // Delete button
-    self.deleteSlot = function(item, event) {
-        // Confirm?
-        if(!self.parent.parent.confirmDeleteHistory() || confirm(glitterTranslate.deleteMsg + ":\n" + item.historyStatus.name() + "\n\n" + glitterTranslate.removeDow1)) {
-            // Are we still processing and it can be stopped?
-            if(item.processingDownload() == 2) {
-                callAPI({
-                    mode: 'cancel_pp',
-                    value: self.id
-                })
-                // All we can do is wait
-            } else {
-                // Delete the item
-                callAPI({
-                    mode: 'history',
-                    name: 'delete',
-                    del_files: 1,
-                    value: self.id
-                }).then(function(response) {
-                    if(response.status) {
-                        // Make sure no flickering (if there are more items left) and then remove
-                        self.parent.isLoading(self.parent.totalItems() > 1)
-                        self.parent.historyItems.remove(self);
-                        self.parent.parent.refresh();
-                    }
-                });
-            }
-
-        }
-    };
 }
\ No newline at end of file
