@@ -27,7 +27,7 @@ import sys
 import threading
 import sqlite3
 from sqlite3 import Connection, Cursor
-from typing import Optional, List, Sequence, Dict, Any, Tuple
+from typing import Optional, List, Sequence, Dict, Any, Tuple, Union
 
 import sabnzbd
 import sabnzbd.cfg
@@ -35,10 +35,10 @@ from sabnzbd.constants import DB_HISTORY_NAME, STAGES, Status, PP_LOOKUP
 from sabnzbd.bpsmeter import this_week, this_month
 from sabnzbd.decorators import synchronized
 from sabnzbd.encoding import ubtou, utob
-from sabnzbd.misc import int_conv, caller_name, opts_to_pp, to_units
+from sabnzbd.misc import caller_name, opts_to_pp, to_units, bool_conv, match_str
 from sabnzbd.filesystem import remove_file, clip_path
 
-DB_LOCK = threading.RLock()
+DB_LOCK = threading.Lock()
 
 
 class HistoryDB:
@@ -50,66 +50,74 @@ class HistoryDB:
 
     # These class attributes will be accessed directly because
     # they need to be shared by all instances
-    db_path = None  # Will contain full path to history database
-    done_cleaning = False  # Ensure we only do one Vacuum per session
+    db_path = None  # Full path to history database
+    startup_done = False
 
     @synchronized(DB_LOCK)
     def __init__(self):
         """Determine database path and create connection"""
         self.connection: Optional[Connection] = None
         self.cursor: Optional[Cursor] = None
-        if not HistoryDB.db_path:
-            HistoryDB.db_path = os.path.join(sabnzbd.cfg.admin_dir.get_path(), DB_HISTORY_NAME)
         self.connect()
 
     def connect(self):
         """Create a connection to the database"""
-        create_table = not os.path.exists(HistoryDB.db_path)
+        if not HistoryDB.db_path:
+            HistoryDB.db_path = os.path.join(sabnzbd.cfg.admin_dir.get_path(), DB_HISTORY_NAME)
+        create_table = not HistoryDB.startup_done and not os.path.exists(HistoryDB.db_path)
+
         self.connection = sqlite3.connect(HistoryDB.db_path)
+        self.connection.isolation_level = None  # autocommit attribute only introduced in Python 3.12
         self.connection.row_factory = sqlite3.Row
         self.cursor = self.connection.cursor()
-        if create_table:
-            self.create_history_db()
-        elif not HistoryDB.done_cleaning:
-            # Run VACUUM on sqlite
+
+        # Perform initialization only once
+        if not HistoryDB.startup_done:
+            if create_table:
+                self.create_history_db()
+
             # When an object (table, index, or trigger) is dropped from the database, it leaves behind empty space
             # http://www.sqlite.org/lang_vacuum.html
-            HistoryDB.done_cleaning = True
             self.execute("VACUUM")
 
-        self.execute("PRAGMA user_version;")
-        try:
-            version = self.cursor.fetchone()["user_version"]
-        except (IndexError, TypeError):
-            version = 0
+            # See if we need to perform any updates
+            self.execute("PRAGMA user_version;")
+            try:
+                version = self.cursor.fetchone()["user_version"]
+            except (IndexError, TypeError):
+                version = 0
 
-        # Add any new columns added since last DB version
-        # Use "and" to stop when database has been reset due to corruption
-        if version < 1:
-            _ = (
-                self.execute("PRAGMA user_version = 1;", save=True)
-                and self.execute("ALTER TABLE history ADD COLUMN series TEXT;", save=True)
-                and self.execute("ALTER TABLE history ADD COLUMN md5sum TEXT;", save=True)
-            )
-        if version < 2:
-            _ = self.execute("PRAGMA user_version = 2;", save=True) and self.execute(
-                "ALTER TABLE history ADD COLUMN password TEXT;", save=True
-            )
-        if version < 3:
-            # Transfer data to new column (requires WHERE-hack), original column should be removed later
-            _ = (
-                self.execute("PRAGMA user_version = 3;", save=True)
-                and self.execute("ALTER TABLE history ADD COLUMN duplicate_key TEXT;", save=True)
-                and self.execute("UPDATE history SET duplicate_key = series WHERE 1 = 1;", save=True)
-            )
+            # Add any new columns added since last DB version
+            # Use "and" to stop when database has been reset due to corruption
+            if version < 1:
+                _ = (
+                    self.execute("PRAGMA user_version = 1;")
+                    and self.execute("ALTER TABLE history ADD COLUMN series TEXT;")
+                    and self.execute("ALTER TABLE history ADD COLUMN md5sum TEXT;")
+                )
+            if version < 2:
+                _ = self.execute("PRAGMA user_version = 2;") and self.execute(
+                    "ALTER TABLE history ADD COLUMN password TEXT;"
+                )
+            if version < 3:
+                # Transfer data to new column (requires WHERE-hack), original column should be removed later
+                _ = (
+                    self.execute("PRAGMA user_version = 3;")
+                    and self.execute("ALTER TABLE history ADD COLUMN duplicate_key TEXT;")
+                    and self.execute("UPDATE history SET duplicate_key = series WHERE 1 = 1;")
+                )
+            if version < 4:
+                _ = self.execute("PRAGMA user_version = 4;") and self.execute(
+                    "ALTER TABLE history ADD COLUMN archive INTEGER;"
+                )
 
-    def execute(self, command: str, args: Sequence = (), save: bool = False) -> bool:
+            HistoryDB.startup_done = True
+
+    def execute(self, command: str, args: Sequence = ()) -> bool:
         """Wrapper for executing SQL commands"""
         for tries in (4, 3, 2, 1, 0):
             try:
                 self.cursor.execute(command, args)
-                if save:
-                    self.connection.commit()
                 return True
             except:
                 error = str(sys.exc_info()[1])
@@ -121,7 +129,7 @@ class HistoryDB:
                     logging.error(T("Cannot write to History database, check access rights!"))
                     # Report back success, because there's no recovery possible
                     return True
-                elif "not a database" in error or "malformed" in error or "duplicate column name" in error:
+                elif match_str(error, ("not a database", "malformed", "no such table", "duplicate column name")):
                     logging.error(T("Damaged History database, created empty replacement"))
                     logging.info("Traceback: ", exc_info=True)
                     self.close()
@@ -129,10 +137,11 @@ class HistoryDB:
                         remove_file(HistoryDB.db_path)
                     except:
                         pass
+                    HistoryDB.startup_done = False
                     self.connect()
                     # Return False in case of "duplicate column" error
                     # because the column addition in connect() must be terminated
-                    return "duplicate column name" not in error
+                    return True
                 else:
                     logging.error(T("SQL Command Failed, see log"))
                     logging.info("SQL: %s", command)
@@ -141,6 +150,7 @@ class HistoryDB:
                     try:
                         self.connection.rollback()
                     except:
+                        # Can fail in case of automatic rollback
                         logging.debug("Rollback Failed:", exc_info=True)
             return False
 
@@ -176,12 +186,12 @@ class HistoryDB:
             "series" TEXT,
             "md5sum" TEXT,
             "password" TEXT,
-            "duplicate_key" TEXT
+            "duplicate_key" TEXT,
+            "archive" INTEGER
         )
-        """,
-            save=True,
+        """
         )
-        self.execute("PRAGMA user_version = 3;", save=True)
+        self.execute("PRAGMA user_version = 4;")
 
     def close(self):
         """Close database connection"""
@@ -192,15 +202,32 @@ class HistoryDB:
             logging.error(T("Failed to close database, see log"))
             logging.info("Traceback: ", exc_info=True)
 
-    def remove_completed(self, search=None):
-        """Remove all completed jobs from the database, optional with `search` pattern"""
+    def archive(self, job: str):
+        """Move job to the archive"""
+        self.execute("""UPDATE history SET archive = 1 WHERE nzo_id = ?""", (job,))
+        logging.info("[%s] Moved job %s to archive", caller_name(), job)
+
+    def remove(self, job: str):
+        """Permanently remove job from the history"""
+        self.execute("""DELETE FROM history WHERE nzo_id = ?""", (job,))
+        logging.info("[%s] Removing job %s from history", caller_name(), job)
+
+    def archive_with_status(self, status: str, search: Optional[str] = None):
+        """Archive all jobs with a specific status, optional with `search` pattern"""
         search = convert_search(search)
-        logging.info("Removing all completed jobs from history")
-        return self.execute(
-            """DELETE FROM history WHERE name LIKE ? AND status = ?""", (search, Status.COMPLETED), save=True
+        logging.info("Archiving all jobs with status=%s", status)
+        self.execute(
+            """UPDATE history SET archive = 1 WHERE archive IS NULL AND name LIKE ? AND status = ?""",
+            (search, status),
         )
 
-    def get_failed_paths(self, search=None):
+    def remove_with_status(self, status: str, search: Optional[str] = None):
+        """Remove all jobs from the database with a specific status, optional with `search` pattern"""
+        search = convert_search(search)
+        logging.info("Removing all jobs with status=%s", status)
+        self.execute("""DELETE FROM history WHERE name LIKE ? AND status = ?""", (search, status))
+
+    def get_failed_paths(self, search: Optional[str] = None) -> List[str]:
         """Return list of all storage paths of failed jobs (may contain non-existing or empty paths)"""
         search = convert_search(search)
         fetch_ok = self.execute(
@@ -211,58 +238,53 @@ class HistoryDB:
         else:
             return []
 
-    def remove_failed(self, search=None):
-        """Remove all failed jobs from the database, optional with `search` pattern"""
-        search = convert_search(search)
-        logging.info("Removing all failed jobs from history")
-        return self.execute(
-            """DELETE FROM history WHERE name LIKE ? AND status = ?""", (search, Status.FAILED), save=True
-        )
-
-    def remove_history(self, jobs=None):
-        """Remove all jobs in the list `jobs`, empty list will remove all completed jobs"""
-        if jobs is None:
-            self.remove_completed()
-        else:
-            if not isinstance(jobs, list):
-                jobs = [jobs]
-
-            for job in jobs:
-                self.execute("""DELETE FROM history WHERE nzo_id = ?""", (job,), save=True)
-                logging.info("[%s] Removing job %s from history", caller_name(), job)
-
     def auto_history_purge(self):
-        """Remove history items based on the configured history-retention"""
-        if sabnzbd.cfg.history_retention() == "0":
+        """Archive or remove history items based on the configured history-retention"""
+        history_retention_option = sabnzbd.cfg.history_retention_option()
+        to_keep = sabnzbd.cfg.history_retention_number()
+
+        if history_retention_option == "all":
             return
-
-        if sabnzbd.cfg.history_retention() == "-1":
+        elif history_retention_option == "number-archive":
+            # Archive if more than X jobs
+            logging.info("Archiving all but last %s completed jobs", to_keep)
+            self.execute(
+                """UPDATE history SET archive = 1 WHERE status = ? AND  archive IS NULL AND id NOT IN (
+                    SELECT id FROM history WHERE status = ? AND archive IS NULL ORDER BY completed DESC LIMIT ?
+                )""",
+                (Status.COMPLETED, Status.COMPLETED, to_keep),
+            )
+        elif history_retention_option == "number-delete":
+            # Delete if more than X jobs
+            logging.info("Removing all but last %s completed jobs from history", to_keep)
+            self.execute(
+                """DELETE FROM history WHERE status = ? AND id NOT IN (
+                    SELECT id FROM history WHERE status = ? ORDER BY completed DESC LIMIT ?
+                )""",
+                (Status.COMPLETED, Status.COMPLETED, to_keep),
+            )
+        elif history_retention_option == "days-archive":
+            # Archive jobs older dan X days
+            seconds_to_keep = int(time.time()) - to_keep * 86400
+            logging.info("Archiving completed jobs older than %s days from history", to_keep)
+            self.execute(
+                """UPDATE history SET archive = 1 WHERE status = ? AND archive IS NULL AND completed < ?""",
+                (Status.COMPLETED, seconds_to_keep),
+            )
+        elif history_retention_option == "days-delete":
+            # Delete jobs older dan X days
+            seconds_to_keep = int(time.time()) - to_keep * 86400
+            logging.info("Removing completed jobs older than %s days from history", to_keep)
+            self.execute(
+                """DELETE FROM history WHERE status = ? AND completed < ?""",
+                (Status.COMPLETED, seconds_to_keep),
+            )
+        elif history_retention_option == "all-archive":
+            # Archive all non-failed ones
+            self.archive_with_status(Status.COMPLETED)
+        elif history_retention_option == "all-delete":
             # Delete all non-failed ones
-            self.remove_completed()
-
-        if "d" in sabnzbd.cfg.history_retention():
-            # How many days to keep?
-            days_to_keep = int_conv(sabnzbd.cfg.history_retention().strip()[:-1])
-            seconds_to_keep = int(time.time()) - days_to_keep * 86400
-            if days_to_keep > 0:
-                logging.info("Removing completed jobs older than %s days from history", days_to_keep)
-                return self.execute(
-                    """DELETE FROM history WHERE status = ? AND completed < ?""",
-                    (Status.COMPLETED, seconds_to_keep),
-                    save=True,
-                )
-        else:
-            # How many to keep?
-            to_keep = int_conv(sabnzbd.cfg.history_retention())
-            if to_keep > 0:
-                logging.info("Removing all but last %s completed jobs from history", to_keep)
-                return self.execute(
-                    """DELETE FROM history WHERE status = ? AND id NOT IN (
-                        SELECT id FROM history WHERE status = ? ORDER BY completed DESC LIMIT ?
-                    )""",
-                    (Status.COMPLETED, Status.COMPLETED, to_keep),
-                    save=True,
-                )
+            self.remove_with_status(Status.COMPLETED)
 
     def add_history_db(self, nzo, storage: str, postproc_time: int, script_output: str, script_line: str):
         """Add a new job entry to the database"""
@@ -274,7 +296,6 @@ class HistoryDB:
             downloaded, fail_message, url_info, bytes, duplicate_key, md5sum, password)
             VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)""",
             t,
-            save=True,
         )
         logging.info("Added job %s to history", nzo.final_name)
 
@@ -282,6 +303,7 @@ class HistoryDB:
         self,
         start: Optional[int] = None,
         limit: Optional[int] = None,
+        archive: Optional[bool] = None,
         search: Optional[str] = None,
         categories: Optional[List[str]] = None,
         statuses: Optional[List[str]] = None,
@@ -291,9 +313,13 @@ class HistoryDB:
         command_args = [convert_search(search)]
 
         post = ""
+        if archive:
+            post += " AND archive = 1"
+        else:
+            post += " AND archive IS NULL"
         if categories:
             categories = ["*" if c == "Default" else c for c in categories]
-            post = " AND (category = ?"
+            post += " AND (category = ?"
             post += " OR category = ? " * (len(categories) - 1)
             post += ")"
             command_args.extend(categories)
@@ -567,9 +593,10 @@ def unpack_history_info(item: sqlite3.Row) -> Dict[str, Any]:
     # The action line and loaded is only available for items in the postproc queue
     item["action_line"] = ""
     item["loaded"] = False
+    item["archive"] = bool(item["archive"])
 
     # Retry and retry for failed URL-fetch
-    item["retry"] = int_conv(item["status"] == Status.FAILED and item["path"] and os.path.exists(item["path"]))
+    item["retry"] = bool_conv(item["status"] == Status.FAILED and item["path"] and os.path.exists(item["path"]))
     if item["report"] == "future":
         item["retry"] = True
 
@@ -577,6 +604,5 @@ def unpack_history_info(item: sqlite3.Row) -> Dict[str, Any]:
 
 
 def scheduled_history_purge():
-    logging.info("Scheduled history purge")
     with HistoryDB() as history_db:
         history_db.auto_history_purge()
