@@ -28,8 +28,9 @@ import urllib.request
 import urllib.parse
 import http.client
 import json
+import apprise
 from threading import Thread
-from typing import Optional, Dict
+from typing import Optional, Dict, Union
 
 import sabnzbd
 import sabnzbd.cfg
@@ -115,6 +116,20 @@ def get_prio(notification_type: str, section: str) -> int:
         return -1000
 
 
+def get_targets(notification_type: str, section: str) -> Union[str, bool, None]:
+    """Check target of `notification_type` in `section` if enabled is set"""
+    try:
+        if sabnzbd.config.get_config(section, "%s_target_%s_enable" % (section, notification_type))() > 0:
+            if result := sabnzbd.config.get_config(section, "%s_target_%s" % (section, notification_type))():
+                return result
+            # Use Default
+            return True
+    except TypeError:
+        logging.debug("Incorrect Notify option %s:%s_target_%s", section, section, notification_type)
+        return False
+    return False
+
+
 def check_cat(section: str, job_cat: str, keyword: Optional[str] = None) -> bool:
     """Check if `job_cat` is enabled in `section`.
     * = All, if no other categories selected.
@@ -165,6 +180,13 @@ def send_notification(
         if sabnzbd.cfg.pushbullet_apikey() and check_classes(notification_type, "pushbullet"):
             Thread(target=send_pushbullet, args=(title, msg, notification_type)).start()
 
+    # Apprise
+    if sabnzbd.cfg.apprise_enable() and check_cat("apprise", job_cat):
+        # it is possible to not define global apprise_urls() but only URLs for a specific type
+        # such as complete or disk_full.
+        if get_targets(notification_type, "apprise"):
+            Thread(target=send_apprise, args=(title, msg, notification_type)).start()
+
     # Notification script.
     if sabnzbd.cfg.nscript_enable() and check_cat("nscript", job_cat):
         if sabnzbd.cfg.nscript_script():
@@ -265,6 +287,92 @@ def send_prowl(title, msg, notification_type, force=False, test=None):
     return ""
 
 
+def send_apprise(title, msg, notification_type, force=False, test=None):
+    """send apprise message"""
+    logging.debug("Sending Apprise notification")
+    if test:
+        urls = test.get("apprise_urls")
+    else:
+        urls = sabnzbd.cfg.apprise_urls()
+
+    # Notification mapper
+    n_map = {
+        # Startup/Shutdown
+        "startup": apprise.common.NotifyType.INFO,
+        # Pause/Resume
+        "pause_resume": apprise.common.NotifyType.INFO,
+        # Added NZB
+        "download": apprise.common.NotifyType.INFO,
+        # Post-processing started
+        "pp": apprise.common.NotifyType.INFO,
+        # Job finished
+        "complete": apprise.common.NotifyType.SUCCESS,
+        # Job failed
+        "failed": apprise.common.NotifyType.FAILURE,
+        # Warning
+        "warning": apprise.common.NotifyType.WARNING,
+        # Error
+        "error": apprise.common.NotifyType.FAILURE,
+        # Disk full
+        "disk_full": apprise.common.NotifyType.WARNING,
+        # Queue finished
+        "queue_done": apprise.common.NotifyType.INFO,
+        # User logged in
+        "new_login": apprise.common.NotifyType.INFO,
+        # Other Messages
+        "other": apprise.common.NotifyType.INFO,
+    }
+
+    # Prepare our Asset Object
+    asset = apprise.AppriseAsset(
+        app_id="SABnzbd",
+        app_desc="SABnzbd Notification",
+        app_url="https://sabnzbd.org/",
+        image_url_logo="https://sabnzbd.org/images/icons/apple-touch-icon-180x180-precomposed.png",
+    )
+
+    # Initialize our Apprise Instance
+    apobj = apprise.Apprise(asset=asset)
+
+    if not test:
+        # Get a list of tags that are set to use the common list
+        if target := get_targets(notification_type, "apprise"):
+            if target is True:
+                if not urls:
+                    # Nothing to notify
+                    logging.warning(T("Failed to send Apprise message - no URLs defined"))
+                    return ""
+                # Use default list
+                apobj.add(urls)
+            elif not apobj.add(target):
+                # Target is string of URLs to over-ride with
+                # Store our URL and assign our key
+                logging.warning("%s - %s", notification_type, T("One or more Apprise URLs could not be loaded."))
+        else:
+            # Nothing to notify
+            return ""
+    else:
+        # Use default list
+        apobj.add(urls)
+
+    try:
+        # The below notifies anything added to our list
+        if not apobj.notify(
+            body=msg,
+            title=title,
+            notify_type=n_map[notification_type],
+            body_format=apprise.NotifyFormat.TEXT,
+        ):
+            return T("Failed to send one or more Apprise Notifications")
+
+    except:
+        logging.warning(T("Failed to send Apprise message"))
+        logging.info("Traceback: ", exc_info=True)
+        return T("Failed to send Apprise message")
+
+    return ""
+
+
 def send_pushover(title, msg, notification_type, force=False, test=None):
     """Send message to pushover"""
     logging.debug("Sending Pushover notification")
