@@ -111,7 +111,7 @@ RE_RAR = re.compile(r"(\.rar|\.r\d\d|\.s\d\d|\.t\d\d|\.u\d\d|\.v\d\d)$", re.I)
 # Trylist
 ##############################################################################
 
-TRYLIST_LOCK = threading.Lock()
+TRYLIST_LOCK = threading.RLock()
 
 
 class TryList:
@@ -129,13 +129,10 @@ class TryList:
         with TRYLIST_LOCK:
             return server in self.try_list
 
-    def all_servers_in_try_list(self, servers: List[Server]) -> bool:
+    def all_servers_in_try_list(self, all_servers: Set[Server]) -> bool:
         """Check if all servers have been tried"""
         with TRYLIST_LOCK:
-            for server in servers:
-                if server not in self.try_list:
-                    return False
-        return True
+            return all_servers.issubset(self.try_list)
 
     def add_to_try_list(self, server: Server):
         """Register server as having been tried already"""
@@ -206,12 +203,25 @@ class Article(TryList):
         self.crc32: Optional[int] = None
         self.nzf: NzbFile = nzf
 
+    @synchronized(TRYLIST_LOCK)
     def reset_try_list(self):
-        """In addition to resetting the try list, also reset fetcher so all servers are tried again"""
+        """In addition to resetting the try list, also reset fetcher so all servers
+        are tried again. Locked so fetcher setting changes are also protected."""
         self.fetcher = None
         self.fetcher_priority = 0
         super().reset_try_list()
 
+    @synchronized(TRYLIST_LOCK)
+    def allow_new_fetcher(self, remove_fetcher_from_try_list: bool = True):
+        """Let article get new fetcher and reset try lists of file and job.
+        Locked so all resets are performed at once"""
+        if remove_fetcher_from_try_list:
+            self.remove_from_try_list(self.fetcher)
+        self.fetcher = None
+        self.tries = 0
+        self.nzf.reset_try_list()
+        self.nzf.nzo.reset_try_list()
+
     def get_article(self, server: Server, servers: List[Server]):
         """Return article when appropriate for specified server"""
         if self.fetcher or self.server_in_try_list(server):
@@ -252,7 +262,7 @@ class Article(TryList):
                 if server.priority >= self.fetcher.priority:
                     self.tries = 0
                     # Allow all servers for this nzo and nzf again (but not this fetcher for this article)
-                    sabnzbd.NzbQueue.reset_try_lists(self, remove_fetcher_from_trylist=False)
+                    self.allow_new_fetcher(remove_fetcher_from_try_list=False)
                     return True
 
         logging.info("Article %s unavailable on all servers, discarding", self.article)
@@ -279,17 +289,6 @@ class Article(TryList):
         self.fetcher_priority = 0
         self.tries = 0
 
-    def __eq__(self, other):
-        """Articles with the same usenet address are the same"""
-        return self.article == other.article
-
-    def __hash__(self):
-        """Required because we implement eq. Articles with the same
-        usenet address can appear in different NZF's. So we make every
-        article object unique, even though it is bad practice.
-        """
-        return id(self)
-
     def __repr__(self):
         return "<Article: article=%s, bytes=%s, art_id=%s>" % (self.article, self.bytes, self.art_id)
 
@@ -434,8 +433,11 @@ class NzbFile(TryList):
         self.add_to_try_list(server)
         return articles
 
+    @synchronized(TRYLIST_LOCK)
     def reset_all_try_lists(self):
-        """Clear all lists of visited servers"""
+        """Reset all try lists. Locked so reset is performed
+        for all items at the same time without chance of another
+        thread changing any of the items while we are resetting"""
         for art in self.articles:
             art.reset_try_list()
         self.reset_try_list()
@@ -484,10 +486,12 @@ class NzbFile(TryList):
         """Assume it's the same file if the number bytes and first article
         are the same or if there are no articles left, use the filenames.
         Some NZB's are just a mess and report different sizes for the same article.
+        We used to compare (__eq__) articles based on article-ID, however, this failed
+        because some NZB's had the same article-ID twice within one NZF.
         """
         if other and (self.bytes == other.bytes or len(self.decodetable) == len(other.decodetable)):
             if self.decodetable and other.decodetable:
-                return self.decodetable[0] == other.decodetable[0]
+                return self.decodetable[0].article == other.decodetable[0].article
             # Fallback to filename comparison
             return self.filename == other.filename
         return False
@@ -836,8 +840,9 @@ class NzbObject(TryList):
             self.password = self.meta.get("password", [None])[0]
 
         # Check if we expect propagation delay
-        if (propagation_delay := self.avg_stamp + float(cfg.propagation_delay() * 60)) > time.time():
-            self.propagation_delay = propagation_delay
+        if propagation_delay := cfg.propagation_delay():
+            if (propagation_delay := self.avg_stamp + float(propagation_delay * 60)) > time.time():
+                self.propagation_delay = propagation_delay
 
         # Run user pre-queue script if set and valid
         if not reuse and make_script_path(cfg.pre_script()):
@@ -1003,7 +1008,11 @@ class NzbObject(TryList):
                 except:
                     logging.debug("The lastrar swap did not go well")
 
+    @synchronized(TRYLIST_LOCK)
     def reset_all_try_lists(self):
+        """Reset all try lists. Locked so reset is performed
+        for all items at the same time without chance of another
+        thread changing any of the items while we are resetting"""
         for nzf in self.files:
             nzf.reset_all_try_lists()
         self.reset_try_list()
@@ -1214,7 +1223,7 @@ class NzbObject(TryList):
         # Abort the job due to failure
         if not job_can_succeed:
             self.fail_msg = T("Aborted, cannot be completed") + " - https://sabnzbd.org/not-complete"
-            self.set_unpack_info("Download", self.fail_msg, unique=False)
+            self.set_unpack_info("Download", self.fail_msg)
             logging.debug('Abort job "%s", due to impossibility to complete it', self.final_name)
             return True, True, True
 
@@ -1444,7 +1453,7 @@ class NzbObject(TryList):
     @synchronized(NZO_LOCK)
     def add_parfile(self, parfile: NzbFile) -> bool:
         """Add parfile to the files to be downloaded
-        Resets trylist just to be sure
+        Resets try list just to be sure
         Adjust download-size accordingly
         Returns False when the file couldn't be added
         """
@@ -1594,7 +1603,8 @@ class NzbObject(TryList):
 
     @synchronized(NZO_LOCK)
     def increase_bad_articles_counter(self, bad_article_type: str):
-        """Record information about bad articles"""
+        """Record information about bad articles. Should be called before
+        register_article, which triggers the availability check."""
         if bad_article_type not in self.nzo_info:
             self.nzo_info[bad_article_type] = 0
         self.nzo_info[bad_article_type] += 1
