@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -25,6 +25,7 @@ import tempfile
 import threading
 import ssl
 import time
+import warnings
 from typing import Optional
 import portend
 from flaky import flaky
@@ -32,6 +33,7 @@ from flaky import flaky
 from tests.testhelper import *
 from sabnzbd import misc
 from sabnzbd import newswrapper
+from sabnzbd.happyeyeballs import AddrInfo
 
 TEST_HOST = "127.0.0.1"
 TEST_PORT = portend.find_available_local_port()
@@ -95,7 +97,11 @@ class TestNewsWrapper:
 
         # Set the options
         if server_tls:
-            server_context.maximum_version = server_tls
+            # Ignore DeprecationWarning about old SSL/TLS settings
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore")
+                server_context.maximum_version = server_tls
+
         server_thread = threading.Thread(target=socket_test_server, args=(server_context,), daemon=True)
         server_thread.start()
 
@@ -107,7 +113,7 @@ class TestNewsWrapper:
         nw.server = mock.Mock()
         nw.server.host = TEST_HOST
         nw.server.port = TEST_PORT
-        nw.server.info = socket.getaddrinfo(TEST_HOST, TEST_PORT, 0, socket.SOCK_STREAM)
+        nw.server.info = AddrInfo(*socket.getaddrinfo(TEST_HOST, TEST_PORT, 0, socket.SOCK_STREAM)[0])
         nw.server.timeout = 10
         nw.server.ssl = True
         nw.server.ssl_context = None
@@ -117,9 +123,9 @@ class TestNewsWrapper:
         # Do we expect failure to connect?
         if not can_connect:
             with pytest.raises(OSError):
-                newswrapper.NNTP(nw, TEST_HOST)
+                newswrapper.NNTP(nw, nw.server.info)
         else:
-            nntp = newswrapper.NNTP(nw, TEST_HOST)
+            nntp = newswrapper.NNTP(nw, nw.server.info)
             assert nntp.sock.recv(len(TEST_DATA)) == TEST_DATA
 
             # Assert SSL data
