@@ -36,9 +36,7 @@ class TestCertGen:
         private_key = generate_key(output_file=os.path.join(SAB_CACHE_DIR, "test_key.pem"))
         assert private_key.key_size == 2048
 
-    @pytest.mark.parametrize(
-        "key_size, file_name", [(512, "test_key.pem"), (1024, "test_123_key.pem"), (4096, "123_key.pem")]
-    )
+    @pytest.mark.parametrize("key_size, file_name", [(1024, "test_123_key.pem"), (4096, "123_key.pem")])
     def test_generate_key_custom(self, key_size, file_name):
         # Generate private key
         private_key = generate_key(key_size=key_size, output_file=os.path.join(SAB_CACHE_DIR, file_name))
